# Problem formulation
I have a simple geometry with a disk inside an annulus, where the inner boundary of the annulus exactly matches the boundary of the disk. The physical model attaches an outwards force on the external boundary of the annulus, pulling it away from the disk. The correct solution is a stretched annulus which doesn't touch the disk.

There are three geometry test cases:
1. the geo file only defines two circles, "other" is an exact copy of "small_circle"
2. the geo file defines three circles, "other" is the full boundary of the annulus so it overlaps with "large_circle" but is disjoint from "small_circle"
3. the geo file defines three circles, "other" is just the inner boundary of the annulus so is fully unique


## Using GMSH format 2
### Case 1: one boundary is duplicated
- gmsh converts the geo into a valid mesh file,
- this is fully converted with ElmerGrid (all names appear in `mesh.names`),
- ElmerSolver runs without error, but the two surfaces are fused rather than "sliding"
```bash
gmsh test_duplicate.geo -format msh2 -2 -clmax 0.1 -o test_mesh.msh
ElmerGrid 14 2 test_mesh.msh -names -out results
ElmerSolver case.sif
```

### Case 2: one boundary has overlap
- gmsh converts the geo into a valid mesh file,
- this is fully converted with ElmerGrid (all names appear in `mesh.names`),
- ElmerSolver produces a valid simulation, the outer ring separates from the inner
```bash
gmsh test_overlap.geo -format msh2 -2 -clmax 0.1 -o test_mesh.msh
ElmerGrid 14 2 test_mesh.msh -names -out results
ElmerSolver case.sif
```

### Case 3: all boundaries are distinct
- gmsh converts the geo into a valid mesh file,
- this is fully converted with ElmerGrid (all names appear in `mesh.names`),
- ElmerSolver produces a valid simulation, the outer ring separates from the inner
```bash
gmsh test_unique.geo -format msh2 -2 -clmax 0.1 -o test_mesh.msh
ElmerGrid 14 2 test_mesh.msh -names -out results
ElmerSolver case.sif
```

## Using GMSH format 3
In all cases gmsh creates a valid mesh but ElmerGrid fails with a seg fault and a message saying that version 3 is unsupported.
For example:
```bash
gmsh test_unique.geo -format msh3 -2 -clmax 0.1 -o test_mesh.msh
ElmerGrid 14 2 test_mesh.msh -names -out results
```


## Using GMSH format 4
### Case 1: small boundary is duplicated
- gmsh converts the geo into a valid mesh file,
- this is partly converted by ElmerGrid, dropping "small_circle2" from names
- ElmerSolver runs without error, but the two surfaces are fused rather than "sliding". Probably boundary 34 has been re-mapped internally so it's a valid but useless definition of the sliding boundary
```bash
gmsh test_duplicate.geo -format msh4 -2 -clmax 0.1 -o test_mesh.msh
ElmerGrid 14 2 test_mesh.msh -names -out results
ElmerSolver case.sif
```

### Case 2: one boundary has overlap
- gmsh converts the geo into a valid mesh file,
- this is partly converted by ElmerGrid, dropping "large_circle" from names
- ElmerSolver runs without error, but the two surfaces are fused rather than "sliding". It looks like no pressure is exerted on the system (no stress and no displacement)
```bash
gmsh test_overlap.geo -format msh4 -2 -clmax 0.1 -o test_mesh.msh
ElmerGrid 14 2 test_mesh.msh -names -out results
ElmerSolver case.sif
```

### Case 3: all boundaries are distinct
- gmsh converts the geo into a valid mesh file,
- this is fully converted with ElmerGrid (all names appear in `mesh.names`),
- ElmerSolver produces a valid simulation, the outer ring separates from the inner
```bash
gmsh test_unique.geo -format msh4 -2 -clmax 0.1 -o test_mesh.msh
ElmerGrid 14 2 test_mesh.msh -names -out results
ElmerSolver case.sif
```

# Summary
Deep-copy of boundaries on the gmsh side is necessary and apparently sufficient for contact simulation, in either supported version. Preservation of duplicate/overlapping names is not consistent, but don't support all features.